==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.md <==
# AmazonSimpleStorageServiceS3OnOutposts


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')
```



| Illustration | AmazonSimpleStorageServiceS3OnOutposts | AmazonSimpleStorageServiceS3OnOutpostsCard | AmazonSimpleStorageServiceS3OnOutpostsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutposts](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutpostsCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutpostsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutpostsGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutpostsGroup.Local.png) |




## AmazonSimpleStorageServiceS3OnOutposts

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutposts
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutposts('AmazonSimpleStorageServiceS3OnOutposts', 'Amazon Simple Storage Service S3 On Outposts', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutposts
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutposts('AmazonSimpleStorageServiceS3OnOutposts', 'Amazon Simple Storage Service S3 On Outposts', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3OnOutpostsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsCard('AmazonSimpleStorageServiceS3OnOutpostsCard', 'Amazon Simple Storage Service S3 On Outposts Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsCard('AmazonSimpleStorageServiceS3OnOutpostsCard', 'Amazon Simple Storage Service S3 On Outposts Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3OnOutpostsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsGroup('AmazonSimpleStorageServiceS3OnOutpostsGroup', 'Amazon Simple Storage Service S3 On Outposts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsGroup('AmazonSimpleStorageServiceS3OnOutpostsGroup', 'Amazon Simple Storage Service S3 On Outposts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.md <==
# AmazonSimpleStorageServiceS3OnOutposts


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')
```



| Illustration | AmazonSimpleStorageServiceS3OnOutposts | AmazonSimpleStorageServiceS3OnOutpostsCard | AmazonSimpleStorageServiceS3OnOutpostsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutposts](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutpostsCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutpostsCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3OnOutpostsGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutpostsGroup.Local.png) |




## AmazonSimpleStorageServiceS3OnOutposts

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutposts
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutposts('AmazonSimpleStorageServiceS3OnOutposts', 'Amazon Simple Storage Service S3 On Outposts', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutposts
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutposts('AmazonSimpleStorageServiceS3OnOutposts', 'Amazon Simple Storage Service S3 On Outposts', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3OnOutpostsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsCard('AmazonSimpleStorageServiceS3OnOutpostsCard', 'Amazon Simple Storage Service S3 On Outposts Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsCard('AmazonSimpleStorageServiceS3OnOutpostsCard', 'Amazon Simple Storage Service S3 On Outposts Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3OnOutpostsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsGroup('AmazonSimpleStorageServiceS3OnOutpostsGroup', 'Amazon Simple Storage Service S3 On Outposts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3OnOutpostsGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3OnOutposts')

' renders the element
AmazonSimpleStorageServiceS3OnOutpostsGroup('AmazonSimpleStorageServiceS3OnOutpostsGroup', 'Amazon Simple Storage Service S3 On Outposts Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
